import setuptools


setuptools.setup(
    name='pipokchmod', # Имя пакета
    version='0.0.1',  # Версия пакета
    author='Nikollai',
    author_email='nikolai_22_05@mail.ru',
    description='My Package',
    packages=setuptools.find_packages(),
 )
